ppbamboo
========

PP's BambooHR Module

PyPI package: `ppbamboo <https://pypi.python.org/pypi/ppbamboo>`__

If you spot any problems or have any improvement ideas then feel free to
open an issue and I will be glad to look into it for you.

Installation
------------

A recommended way of installing the tool is pip install.

pip install
~~~~~~~~~~~

The tool is available in PyPI and can be installed using pip:

::

   $ pip install --user ppbamboo
